==> knews-0.9.3.tar.gz: knews-0.9.3/Widgets/TextField.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef _TextField_h
#define _TextField_h

#ifndef XtCBorderIn
#define XtCBorderIn "BorderIn"
#endif
#ifndef XtCBuffer
#define XtCBuffer "Buffer"
#endif
#ifndef XtCDisplayCaret
#define XtCDisplayCaret "DisplayCaret"
#endif
#ifndef XtCInternalHeight
#define XtCInternalHeight "InternalHeight"
#endif
#ifndef XtCInternalWidth
#define XtCInternalWidth "InternalWidth"
#endif
#ifndef XtCPreferredChars
#define XtCPreferredChars "PreferredChars"
#endif
#ifndef XtCFocusRoot
#define XtCFocusRoot "FocusRoot"
#endif
#ifndef XtCHack
#define XtCHack "Hack"
#endif
#ifndef XtCDebug
#define XtCDebug "Debug"
#endif

#ifndef XtNborderIn
#define XtNborderIn "borderIn"
#endif
#ifndef XtBbuffer
#define XtNbuffer "buffer"
#endif
#ifndef XtNdisplayCaret
#define XtNdisplayCaret "displayCaret"
#endif
#ifndef XtNhighlightBackground
#define XtNhighlightBackground "highlightForeground"
#endif
#ifndef XtNhighlightForeground
#define XtNhighlightForeground "highlightForeground"
#endif
#ifndef XtNpreferredChars
#define XtNpreferredChars "preferredChars"
#endif
#ifndef XtNfocusRoot
#define XtNfocusRoot "focusRoot"
#endif
#ifndef XtNtabCallback
#define XtNtabCallback "tabCallback"
#endif
#ifndef XtNfocusCallback
#define XtNfocusCallback "focusCallback"
#endif
#ifndef XtNfocusHack
#define XtNfocusHack "focusHack"
#endif
#ifndef XtNprintFocus
#define XtNprintFocus "printFocus"
#endif

typedef struct _TextFieldClassRec*	TextFieldWidgetClass;
typedef struct _TextFieldRec*		TextFieldWidget;

extern WidgetClass textFieldWidgetClass;

#endif /* _TextField_h */

==> knews-0.9.6-4.tar.gz: knews-0.9.6/Widgets/TextField.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef TextField_h
#define TextField_h

#ifndef XtCBorderIn
#define XtCBorderIn "BorderIn"
#endif
#ifndef XtCBuffer
#define XtCBuffer "Buffer"
#endif
#ifndef XtCDisplayCaret
#define XtCDisplayCaret "DisplayCaret"
#endif
#ifndef XtCInternalHeight
#define XtCInternalHeight "InternalHeight"
#endif
#ifndef XtCInternalWidth
#define XtCInternalWidth "InternalWidth"
#endif
#ifndef XtCPreferredChars
#define XtCPreferredChars "PreferredChars"
#endif
#ifndef XtCFocusRoot
#define XtCFocusRoot "FocusRoot"
#endif
#ifndef XtCHack
#define XtCHack "Hack"
#endif
#ifndef XtCDebug
#define XtCDebug "Debug"
#endif

#ifndef XtNborderIn
#define XtNborderIn "borderIn"
#endif
#ifndef XtBbuffer
#define XtNbuffer "buffer"
#endif
#ifndef XtNdisplayCaret
#define XtNdisplayCaret "displayCaret"
#endif
#ifndef XtNfocusColor
#define XtNfocusColor "focusColor"
#endif
#ifndef XtNhighlightBackground
#define XtNhighlightBackground "highlightForeground"
#endif
#ifndef XtNhighlightForeground
#define XtNhighlightForeground "highlightForeground"
#endif
#ifndef XtNpreferredChars
#define XtNpreferredChars "preferredChars"
#endif
#ifndef XtNfocusRoot
#define XtNfocusRoot "focusRoot"
#endif
#ifndef XtNtabCallback
#define XtNtabCallback "tabCallback"
#endif
#ifndef XtNfocusCallback
#define XtNfocusCallback "focusCallback"
#endif
#ifndef XtNfocusHack
#define XtNfocusHack "focusHack"
#endif
#ifndef XtNprintFocus
#define XtNprintFocus "printFocus"
#endif

typedef struct TextFieldClassRec*	TextFieldWidgetClass;
typedef struct TextFieldRec*		TextFieldWidget;

extern WidgetClass textFieldWidgetClass;

extern void TextFieldSetActive(Widget, int);
extern void TextFieldSetBuffer(Widget, char*);

#endif /* TextField_h */
